# CameraRequest


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**active** | **bool** |  | [optional] 
**device** | **int** |  | 
**name** | **str** | Descriptive name to identify this camera | [optional] [default to 'Raspberry Pi Cam']
**camera_type** | [**CameraType**](CameraType.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


